@@ -20,21 +20,26 @@ async def http_post_json(url, payload={}, headers={}):
     return await _http_request_json(url, 'POST', payload, headers)
 
 
-async def http_get_raw(url, headers={}):
+async def http_get(url, headers={}):
     global _client_session
     if _client_session is None:
-        _client_session = aiohttp.ClientSession()
+        _client_session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=600))
     session = _client_session
     async with session.get(url, ssl=False, headers=headers) as r:
-        if not (r.status >= 200 and r.status < 300):
-            raise CommError(f'{url} raw get request returns {r.status}', await r.read())
-        return await r.read()
+        return r, await r.read()
+
+
+async def http_get_raw(url, headers={}):
+    r = http_get(url, headers)
+    if not (r.status >= 200 and r.status < 300):
+        raise CommError(f'{url} raw get request returns {r.status}', await r.read())
+    return await r.read()
 
 
 async def _http_request_json(url, method, payload, headers={}):
     global _client_session
     if _client_session is None:
-        _client_session = aiohttp.ClientSession()
+        _client_session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=600))
     session = _client_session
     if method == 'GET':
         async with session.get(url, ssl=False, headers=headers) as r:
