@@ -176,7 +176,7 @@ class TracePoint(BaseModel):
 
 
 class MatchResponse(Response):
-    tracepoints: Optional[List[TracePoint]]
+    tracepoints: Optional[List[Optional[TracePoint]]]
     matchings: Optional[List[Route]]
 
     @classmethod
@@ -276,9 +276,9 @@ class API:
         url = f'{self.base_url}/match/v1/driving/{coords_param}.{output_format}'
         params = {}
         if timestamps is not None:
-            params['timestamps'] = ";".join(timestamps)
+            params['timestamps'] = ";".join([str(x) for x in timestamps])
         if radiuses is not None:
-            params['radiuses'] = ";".join(radiuses)
+            params['radiuses'] = ";".join([str(x) for x in radiuses])
         params['gaps'] = gaps.value
         if tidy:
             params['tidy'] = "true"
