@@ -25,7 +25,7 @@ def register(metric_type, name, desc, labels):
 def collect():
     s = pd.generate_latest()
     for _,c in counters.items():
-        c._metrics = {}
+        c._metric_init()
     for _,h in histograms.items():
-        h._metrics = {}
+        h._metric_init()
     return s
